============================
So You Want to Contribute...
============================

For general information on contributing to OpenStack, please check out the
`contributor guide <https://docs.openstack.org/contributors/>`_ to get started.
It covers all the basics that are common to all OpenStack projects: the
accounts you need, the basics of interacting with our Gerrit review system,
how we communicate as a community, etc.

Below will cover the more project specific information you need to get started
with Zun.

Communication
~~~~~~~~~~~~~
- IRC channel: #openstack-zun
- Mailing list's prefix: [zun]
- Office Hours:

  This is general Zun team meeting. Anyone can bring up a topic to discuss
  with the Zun team.

  - time: http://eavesdrop.openstack.org/#Zun_Team_Meeting

Contacting the Core Team
~~~~~~~~~~~~~~~~~~~~~~~~
The list of current Zun core reviewers is available on `gerrit
<https://review.opendev.org/#/admin/groups/1382,members>`_.

New Feature Planning
~~~~~~~~~~~~~~~~~~~~
Zun team uses Launchpad to propose new features.
A blueprint should be submitted in Launchpad first.
Such blueprints need to be discussed and approved by the `Zun
driver team <https://launchpad.net/~zun-drivers>`_

Task Tracking
~~~~~~~~~~~~~
We track our tasks in Launchpad

   https://bugs.launchpad.net/zun

If you're looking for some smaller, easier work item to pick up and get started
on, search for the 'low-hanging-fruit' tag.

.. NOTE: If your tag is not 'low-hanging-fruit' please change the text above.

Reporting a Bug
~~~~~~~~~~~~~~~
You found an issue and want to make sure we are aware of it? You can do so on
`Launchpad
<https://bugs.launchpad.net/zun>`_.

Getting Your Patch Merged
~~~~~~~~~~~~~~~~~~~~~~~~~
All changes proposed to the Zun project
require one or two +2 votes from Zun core reviewers before one of the core
reviewers can approve patch by giving ``Workflow +1`` vote.

Project Team Lead Duties
~~~~~~~~~~~~~~~~~~~~~~~~
All common PTL duties are enumerated in the `PTL guide
<https://docs.openstack.org/project-team-guide/ptl.html>`_.
